@@ -202,13 +202,13 @@ class FloatingIPsClient(ClientEntityBase, GetEntityByNameMixin):
         """
         params = {}
 
-        if label_selector:
+        if label_selector is not None:
             params['label_selector'] = label_selector
-        if page:
+        if page is not None:
             params['page'] = page
-        if per_page:
+        if per_page is not None:
             params['per_page'] = per_page
-        if name:
+        if name is not None:
             params['name'] = name
 
         response = self._client.request(url="/floating_ips", method="GET", params=params)
@@ -244,7 +244,7 @@ class FloatingIPsClient(ClientEntityBase, GetEntityByNameMixin):
                labels=None,  # type: Optional[str]
                home_location=None,  # type: Optional[Location]
                server=None,  # type: Optional[Server]
-               name=None,  # type: Optinal[str]
+               name=None,  # type: Optional[str]
                ):
         # type: (...) -> CreateFloatingIPResponse
         """Creates a new Floating IP assigned to a server.
